Description
===========

An implementation of EWMH (Extended Window Manager Hints) for python, based on Xlib.
It intends to give a control on windows for compliants window managers.

Installation
------------

With python3, it'easy as:

.. code-block:: python
  
  pip install ewmh

Unfortunately for python 2 users, you will have to manually install
the required dependency **Xlib** from https://pypi.python.org/pypi/python-xlib/0.12,
until the xlib developpers send a version for python2 on PyPi.

Once this is done, just

.. code-block:: python
  
  python setup.py install

This will do the work.

Documentation
-------------

Online documentation is available here: http://ewmh.readthedocs.org/en/latest/.
